@@ -7,28 +7,29 @@
 #' @param size the number of clusters to be drawn out.
 #' @param p.col,p.cex different colors / magnification rate to annotate the
 #'   population and the sample
-#' @param \dots other arguments passed to \code{\link[graphics]{rect}} to
-#'   annotate the ``clusters''
+#' @param \dots other arguments passed to \code{\link{rect}} to annotate the
+#'   ``clusters''
 #' @return None (invisible \code{NULL}).
-#' @author Yihui Xie <\url{http://yihui.name}>
-#' @seealso \code{\link[base]{sample}}, \code{\link{sample.simple}},
+#' @author Yihui Xie
+#' @seealso \code{\link{sample}}, \code{\link{sample.simple}},
 #'   \code{\link{sample.ratio}}, \code{\link{sample.strat}},
 #'   \code{\link{sample.system}}
-#' @references \url{http://animation.yihui.name/samp:cluster_sampling}
-#' @keywords distribution dynamic
+#' @export
 #' @example inst/examples/sample.cluster-ex.R
-sample.cluster = function(pop = ceiling(10 * runif(10, 0.2, 1)), size = 3,
-                          p.col = c("blue", "red"), p.cex = c(1, 3), ...) {
+sample.cluster = function(
+  pop = ceiling(10 * runif(10, 0.2, 1)), size = 3, p.col = c('blue', 'red'),
+  p.cex = c(1, 3), ...
+) {
   if (size > length(pop))
-    stop("sample size must be smaller than the number of clusters")
+    stop('sample size must be smaller than the number of clusters')
   ncol = max(pop)
   nrow = length(pop)
-  nmax = ani.options("nmax")
+  nmax = ani.options('nmax')
   for (i in 1:nmax) {
     dev.hold()
-    plot(1, axes = FALSE, ann = FALSE, type = "n",
-         xlim = c(0.5, ncol + 0.5), ylim = c(0.5, nrow + 0.5), xaxs = "i",
-         yaxs = "i", xlab = "", ylab = "")
+    plot(1, axes = FALSE, ann = FALSE, type = 'n',
+         xlim = c(0.5, ncol + 0.5), ylim = c(0.5, nrow + 0.5), xaxs = 'i',
+         yaxs = 'i', xlab = '', ylab = '')
     rect(rep(0.5, nrow), seq(0.5, nrow, 1),
          rep(ncol + 0.5, nrow), seq(1.5, nrow + 1, 1), lwd = 1, ...)
     idx = sample(nrow, size)
