@@ -14,24 +14,24 @@
 #'   population and sample respectively
 #' @param m.col color for the horizontal line to denote the sample mean of Y
 #' @param legend.loc legend location: topleft, topright, bottomleft,
-#'   bottomright, ... (see \code{\link[graphics]{legend}})
-#' @param \dots other arguments passed to \code{\link[graphics]{plot.default}}
+#'   bottomright, ... (see \code{\link{legend}})
+#' @param \dots other arguments passed to \code{\link{plot.default}}
 #' @return A list containing \item{X}{X population} \item{Y}{Y population}
 #'   \item{R}{population ratio} \item{r}{ratio calculated from samples}
 #'   \item{Ybar}{population mean of Y} \item{ybar.simple}{simple sample mean of
 #'   Y} \item{ybar.ratio}{sample mean of Y via ratio estimation}
-#' @author Yihui Xie <\url{http://yihui.name}>
-#' @seealso \code{\link[base]{sample}}, \code{\link{sample.simple}},
+#' @author Yihui Xie
+#' @seealso \code{\link{sample}}, \code{\link{sample.simple}},
 #'   \code{\link{sample.cluster}}, \code{\link{sample.strat}},
 #'   \code{\link{sample.system}}
-#' @references \url{http://animation.yihui.name/samp:ratio_estimation}
-#' @keywords dynamic
+#' @export
 #' @example inst/examples/sample.ratio-ex.R
-sample.ratio = function(X = runif(50, 0, 5), R = 1, Y = R * X + rnorm(X),
-                        size = length(X)/2, p.col = c("blue", "red"),
-                        p.cex = c(1, 3), p.pch = c(20, 21), m.col = c("black", "gray"),
-                        legend.loc = "topleft", ...) {
-  nmax = ani.options("nmax")
+sample.ratio = function(
+  X = runif(50, 0, 5), R = 1, Y = R * X + rnorm(X), size = length(X)/2,
+  p.col = c('blue', 'red'), p.cex = c(1, 3), p.pch = c(20, 21),
+  m.col = c('black', 'gray'), legend.loc = 'topleft', ...
+) {
+  nmax = ani.options('nmax')
   N = length(X)
   r = est1 = est2 = numeric(nmax)
   for (i in 1:nmax) {
@@ -42,11 +42,14 @@ sample.ratio = function(X = runif(50, 0, 5), R = 1, Y = R * X + rnorm(X),
     abline(v = c(mean(X), mean(X[idx])), h = c(mean(Y), est1[i] <- mean(Y[idx])),
            col = m.col, lty = c(2, 1))
     abline(h = est2[i] <- mean(X) * (r[i] <- est1[i]/mean(X[idx])), col = p.col[2])
-    legend(legend.loc, expression(bar(X), bar(x), bar(X) %.%
-      (bar(y)/bar(x)), bar(Y), bar(y)), lty = c(2, 1, 1, 2, 1),
-           col = c(m.col[c(1, 2)], p.col[2], m.col[c(1, 2)]), bty = "n", ncol = 2)
+    legend(
+      legend.loc, expression(bar(X), bar(x), bar(X) %.% (bar(y)/bar(x)), bar(Y), bar(y)),
+      lty = c(2, 1, 1, 2, 1), col = c(m.col[c(1, 2)], p.col[2], m.col[c(1, 2)]),
+      bty = 'n', ncol = 2
+    )
     ani.pause()
   }
-  invisible(list(X = X, Y = Y, R = R, r = r, Ybar = mean(Y),
-                 ybar.simple = est1, ybar.ratio = est2))
+  invisible(
+    list(X = X, Y = Y, R = R, r = r, Ybar = mean(Y), ybar.simple = est1, ybar.ratio = est2)
+  )
 }
