@@ -10,15 +10,17 @@
 #' where \code{interval} comes from \code{ani.options('interval')}, and
 #' \code{ani.type} is from \code{ani.options('ani.type')}. For more details on
 #' the numerous options of FFmpeg, please see the reference.
+#' 
+#' Some linux systems may use the alternate software 'avconv' instead of 'ffmpeg'.  The package will attempt to determine which command is present and set \code{\link{ani.options}('ffmpeg')} to an appropriate default value. This can be overridden by passing in the \code{ffmpeg} argument. 
 #' @param expr the R code to draw (several) plots
 #' @param img.name the file name of the sequence of images to be generated
 #' @param video.name the file name of the output video (e.g.
 #'   \file{animation.mp4} or \file{animation.avi})
 #' @param ffmpeg the command to call FFmpeg (e.g.
-#'   \code{'C:/Software/ffmpeg/bin/ffmpeg.exe'} under Windows); note the full
+#'   \code{'C:/Software/ffmpeg/bin/ffmpeg.exe'} under Windows or 'avconv' on some linux machines); note the full
 #'   path of FFmpeg can be pre-specified in \code{\link{ani.options}('ffmpeg')}
 #' @param other.opts other options to be passed to \code{ffmpeg}, e.g. we can
-#'   specify the bitrate as \code{other.opts = '-b 400k'}
+#'   specify the bitrate as \code{other.opts = '-b 400k'} (The default \code{"-pix_fmt yuv420p"} is a work-around for a bug in some versions of ffmpeg.)
 #' @param ... other arguments to be passed to \code{\link{ani.options}}
 #' @return An integer indicating failure (-1) or success (0) of the converting
 #'   (refer to \code{\link{system}}).
@@ -33,22 +35,23 @@
 #' @export
 #' @example inst/examples/saveVideo-ex.R
 saveVideo = function(
-  expr, video.name = 'animation.mp4', img.name = 'Rplot', ffmpeg = 'ffmpeg',
+  expr, video.name = 'animation.mp4', img.name = 'Rplot', ffmpeg = ani.options('ffmpeg'),
   other.opts = if (grepl('[.]mp4$', video.name)) '-pix_fmt yuv420p', ...
 ) {
   oopt = ani.options(...)
   on.exit(ani.options(oopt))
   owd = setwd(tempdir())
   on.exit(setwd(owd), add = TRUE)
-
-  if (!is.null(ani.options('ffmpeg'))) {
-    ffmpeg = ani.options('ffmpeg')
+  
+  # default ffmpeg command to 'ffmpeg' if not specified
+  if (is.null(ffmpeg)) {
+    ffmpeg = 'ffmpeg'
   }
   if (!grepl('^["\']', ffmpeg)) ffmpeg = shQuote(ffmpeg)
 
   version = try(system(paste(ffmpeg, '-version'), intern = TRUE))
   if (inherits(version, 'try-error')) {
-    warning('The command "', ffmpeg, '" is not available in your system. Please install FFmpeg first: ',
+    warning('The command "', ffmpeg, '" is not available in your system. Please install FFmpeg or avconv first: ',
             ifelse(.Platform$OS.type == 'windows', 'http://ffmpeg.arrozcru.org/autobuilds/',
                    'http://ffmpeg.org/download.html'))
     return()
@@ -78,7 +81,7 @@ saveVideo = function(
 
   if (cmd == 0) {
     setwd(owd)
-    file.copy(file.path(tempdir(), basename(video.name)), video.name)
+    file.copy(file.path(tempdir(), basename(video.name)), video.name, overwrite = TRUE)
     message('\n\nVideo has been created at: ',
             output.path <- normalizePath(video.name))
     auto_browse(output.path)
